export.download_and_combine()
Download all survey data for the given survey IDs and combine into a single DataFrame.
Usage
export.download_and_combine(
sids_df,
ubb,
)Keeps all audiences; filtering happens later per report if needed.
Download all survey data for the given survey IDs and combine into a single DataFrame.
Usage
Keeps all audiences; filtering happens later per report if needed.