limer_n()
Get the number of completed responses of a LimeSurvey survey.
Usage
limer_n(id)Parameters
id: int- LimeSurvey survey ID.
Returns
pd.DataFrame- DataFrame with columns: ‘sid’ and ‘completed_responses’.
Get the number of completed responses of a LimeSurvey survey.
Usage
id: int pd.DataFrame